@@ -5,7 +5,7 @@ import sys
 from toot import api, config
 from toot.auth import login_interactive, login_browser_interactive, create_app_interactive
 from toot.exceptions import ConsoleError, NotFoundError
-from toot.output import (print_out, print_instance, print_account,
+from toot.output import (print_out, print_instance, print_account, print_acct_list,
                          print_search_results, print_timeline, print_notifications)
 from toot.utils import assert_domain_exists, editor_input, multiline_input, EOF_KEY
 
@@ -164,6 +164,16 @@ def unpin(app, user, args):
     print_out("<green>✓ Status unpinned</green>")
 
 
+def bookmark(app, user, args):
+    api.bookmark(app, user, args.status_id)
+    print_out("<green>✓ Status bookmarked</green>")
+
+
+def unbookmark(app, user, args):
+    api.unbookmark(app, user, args.status_id)
+    print_out("<green>✓ Status unbookmarked</green>")
+
+
 def reblogged_by(app, user, args):
     for account in api.reblogged_by(app, user, args.status_id):
         print_out("{}\n @{}".format(account['display_name'], account['acct']))
@@ -269,6 +279,16 @@ def unfollow(app, user, args):
     api.unfollow(app, user, account['id'])
     print_out("<green>✓ You are no longer following {}</green>".format(args.account))
 
+def following(app, user, args):
+    account = _find_account(app, user, args.account)
+    response = api.following(app, user, account['id'])
+    print_acct_list(response)
+
+def followers(app, user, args):
+    account = _find_account(app, user, args.account)
+    response = api.followers(app, user, account['id'])
+    print_acct_list(response)
+
 
 def mute(app, user, args):
     account = _find_account(app, user, args.account)
