@@ -108,7 +108,7 @@ scheme_arg = (["--disable-https"], {
 
 status_id_arg = (["status_id"], {
     "help": "ID of the status",
-    "type": int,
+    "type": str,
 })
 
 # Arguments for selecting a timeline (see `toot.commands.get_timeline_generator`)
@@ -132,7 +132,7 @@ common_timeline_args = [
         "help": "mastodon instance from which to read (public and tag timelines only)",
     }),
     (["--list"], {
-        "type": int,
+        "type": str,
         "help": "show timeline for given list.",
     }),
 ]
@@ -155,14 +155,6 @@ timeline_args = common_timeline_args + [
     }),
 ]
 
-curses_args = common_timeline_args + [
-    (["-c", "--count"], {
-        "type": timeline_count,
-        "help": "number of toots to show per page (1-20, default 20).",
-        "default": 20,
-    }),
-]
-
 AUTH_COMMANDS = [
     Command(
         name="login",
@@ -203,12 +195,6 @@ TUI_COMMANDS = [
         arguments=[],
         require_auth=True,
     ),
-    Command(
-        name="curses",
-        description="An experimental timeline app (DEPRECATED, use 'toot tui' instead)",
-        arguments=curses_args,
-        require_auth=False,
-    ),
 ]
 
 
@@ -243,6 +229,11 @@ READ_COMMANDS = [
                 "default": False,
                 "help": "Reverse the order of the shown notifications (newest on top)",
             }),
+            (["-m", "--mentions"], {
+                "action": "store_true",
+                "default": False,
+                "help": "Only print mentions",
+            })
         ],
         require_auth=True,
     ),
@@ -306,6 +297,12 @@ POST_COMMANDS = [
                 "help": "path to the media file to attach (specify multiple "
                         "times to attach up to 4 files)"
             }),
+            (["-d", "--description"], {
+                "action": "append",
+                "type": str,
+                "help": "plain-text description of the media for accessibility "
+                        "purposes, one per attached media"
+            }),
             (["-v", "--visibility"], {
                 "type": visibility,
                 "default": "public",
@@ -321,7 +318,7 @@ POST_COMMANDS = [
                 "help": "text to be shown as a warning before the actual content",
             }),
             (["-r", "--reply-to"], {
-                "type": int,
+                "type": str,
                 "help": "local ID of the status you want to reply to",
             }),
             (["-l", "--language"], {
@@ -335,6 +332,15 @@ POST_COMMANDS = [
                 "help": "Specify an editor to compose your toot, "
                         "defaults to editor defined in $EDITOR env variable.",
             }),
+            (["--scheduled-at"], {
+                "type": str,
+                "help": "ISO 8601 Datetime at which to schedule a status. Must "
+                        "be at least 5 minutes in the future.",
+            }),
+            (["-t", "--content-type"], {
+                "type": str,
+                "help": "MIME type for the status text (not supported on all instances)",
+            }),
         ],
         require_auth=True,
     ),
@@ -345,7 +351,11 @@ POST_COMMANDS = [
             (["file"], {
                 "help": "Path to the file to upload",
                 "type": FileType('rb')
-            })
+            }),
+            (["-d", "--description"], {
+                "type": str,
+                "help": "plain-text description of the media for accessibility purposes"
+            }),
         ],
         require_auth=True,
     ),
@@ -400,6 +410,18 @@ STATUS_COMMANDS = [
         arguments=[status_id_arg],
         require_auth=True,
     ),
+    Command(
+        name="bookmark",
+        description="Bookmark a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
+    Command(
+        name="unbookmark",
+        description="Unbookmark a status",
+        arguments=[status_id_arg],
+        require_auth=True,
+    ),
 ]
 
 ACCOUNTS_COMMANDS = [
@@ -419,6 +441,22 @@ ACCOUNTS_COMMANDS = [
         ],
         require_auth=True,
     ),
+    Command(
+        name="following",
+        description="List accounts following the given account",
+        arguments=[
+            account_arg,
+        ],
+        require_auth=True,
+    ),
+    Command(
+        name="followers",
+        description="List accounts followed by the given account",
+        arguments=[
+            account_arg,
+        ],
+        require_auth=True,
+    ),
     Command(
         name="mute",
         description="Mute an account",
